Option Explicit On
Option Strict On

Imports System
Imports System.Windows.Forms

Namespace OrderPlacingSample

   Module ErrorHandler
      ''' <summary>
      ''' Shows pop-up with specified error message.
      ''' </summary>
      ''' <param name="message">Error description.</param>
      ''' <param name="caption">Pop-up window caption.</param>
      ''' <param name="owner">Owner of this pop-up window.</param>
      Public Sub ShowErrorMessage(ByVal message As String, _
                                  ByVal caption As String, _
                                  ByVal owner As Form)
         If caption = String.Empty Then
            caption = "Error"
         End If

         If owner Is Nothing Then
            MessageBox.Show(message, caption, MessageBoxButtons.OK, MessageBoxIcon.Hand)
         Else
            MessageBox.Show(owner, message, caption, MessageBoxButtons.OK, MessageBoxIcon.Hand)
         End If
      End Sub

      ''' <summary>
      ''' Creates error message.
      ''' </summary>
      ''' <param name="modName">Module name, which handles an error Or in which the error has occured.</param>
      ''' <param name="funcName">Function name, which handles an error Or in which the error has occured.</param>
      ''' <param name="errorDescription">Error description.</param>
      Private Function getErrorMessage(ByVal modName As String, ByVal funcName As String, ByVal errorDescription As String) As String
         Return "Module: " & modName & Environment.NewLine &
                "Function: " & funcName & Environment.NewLine &
                "Error Description: " & errorDescription
      End Function

      ''' <summary>
      ''' Shows pop-up window with specified exception information.
      ''' </summary>
      ''' <param name="modName">Module name, in which the exception has occurred.</param>
      ''' <param name="funcName">Function name, in which the exception has occurred.</param>
      ''' <param name="ex">The exception generated in the described function of the described module.</param>
      Public Sub HandleError(ByVal modName As String, _
                             ByVal funcName As String, _
                             ByVal ex As Exception)
         MessageBox.Show(getErrorMessage(modName, funcName, ex.Message), "OrderPlacing",
                         MessageBoxButtons.OK, MessageBoxIcon.Error)
      End Sub

      ''' <summary>
      ''' Handles the error and shows a message box.
      ''' </summary>
      ''' <param name="modName">Module name, in which the exception has occurred.</param>
      ''' <param name="funcName">Function name, in which the exception has occurred.</param>
      ''' <param name="cqg_error"> CQGError object.</param>
      Public Sub HandleError(ByVal modName As String,
                             ByVal funcName As String,
                             ByVal cqg_error As CQG.CQGError)
         MessageBox.Show(getErrorMessage(modName, funcName, cqg_error.Description),
                         "OrderPlacing", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
      End Sub

   End Module

End Namespace